Index: src/interpreter/interpreter.h |
diff --git a/src/interpreter/interpreter.h b/src/interpreter/interpreter.h |
index f4237b3ad2cf13d74c811bd71f539176cdb580c7..1e4ca5cdb80b1ef5e173dea1165d8a3c4741f8c3 100644 |
--- a/src/interpreter/interpreter.h |
+++ b/src/interpreter/interpreter.h |
@@ -11,6 +11,7 @@ |
#include "src/base/macros.h" |
#include "src/builtins.h" |
#include "src/interpreter/bytecodes.h" |
+#include "src/runtime/runtime.h" |
namespace v8 { |
namespace internal { |
@@ -48,8 +49,8 @@ class Interpreter { |
BYTECODE_LIST(DECLARE_BYTECODE_HANDLER_GENERATOR) |
#undef DECLARE_BYTECODE_HANDLER_GENERATOR |
- // Generates code to perform the binary operations via |binop_builtin|. |
- void DoBinaryOp(int builtin_context_index, |
+ // Generates code to perform the binary operations via |function_id|. |
+ void DoBinaryOp(Runtime::FunctionId function_id, |
compiler::InterpreterAssembler* assembler); |
// Generates code to perform a property load via |ic|. |